import ContentPane = require("./layout/ContentPane");
import _TemplatedMixin = require("./_TemplatedMixin");
import _FormMixin = require("./form/_FormMixin");
import _DialogMixin = require("./_DialogMixin");
import { _WidgetBaseConstructor } from "./_WidgetBase";
import { PlaceCorner, PlacePosition } from "./place";

interface TooltipDialog extends ContentPane, _TemplatedMixin, _FormMixin, _DialogMixin {
    /**
     * Description of tooltip dialog (required for a11y)
     */
    title: string;

    /**
     * Don't change this parameter from the default value.
     * This ContentPane parameter doesn't make sense for TooltipDialog, since TooltipDialog
     * is never a child of a layout container, nor can you specify the size of
     * TooltipDialog in order to control the size of an inner widget.
     */
    doLayout: boolean;

    /**
     * A Toggle to modify the default focus behavior of a Dialog, which
     * is to focus on the first dialog element after opening the dialog.
     * False will disable autofocusing.  Default: true.
     */
    autofocus: boolean;

    /**
     * The pointer to the first focusable node in the dialog.
     */
    _firstFocusItem: any;

    /**
     * The pointer to which node has focus prior to our dialog.
     */
    _lastFocusItem: any;

    /**
     * Configure widget to be displayed in given position relative to the button.
     *
     * This is called from the dijit.popup code, and should not be called directly.
     */
    orient(node: Node | HTMLElement, aroundCorner: PlaceCorner, tooltipCorner: PlaceCorner): void;

    /**
     * Focus on first field
     */
    focus(): void;

    /**
     * Called when dialog is displayed.
     *
     * This is called from the dijit.popup code, and should not be called directly.
     */
    onOpen(pos: {
        aroundCorner: PlaceCorner
        aroundNodePos: PlacePosition
        corner: PlaceCorner
        x: number
        y: number
    }): void;

    /**
     * Handler for keydown events
     *
     * Keep keyboard focus in dialog; close dialog on escape key
     */
    _onKey(evt: KeyboardEvent): void;
}

interface TooltipDialogConstructor extends _WidgetBaseConstructor<TooltipDialog> { }

declare const TooltipDialog: TooltipDialogConstructor;
export = TooltipDialog;
